@@ -1,8 +1,9 @@
+use plotlib::view::View;
 use plotlib::repr::Plot;
-use crate::data::Data;
+
 
 /// Plottables can be made into plotlib Plots
-pub trait Plotable: Data {
+pub trait Plotable {
     /// Returns a plotlib Plot representing this object
-    fn plot(&self) -> Plot;
+    fn plot(&self) -> Box<dyn View>;
 }
